summaryrefslogtreecommitdiffstats
path: root/include/unotools
diff options
context:
space:
mode:
Diffstat (limited to 'include/unotools')
-rw-r--r--include/unotools/accessiblerelationsethelper.hxx30
-rw-r--r--include/unotools/accessiblestatesethelper.hxx28
-rw-r--r--include/unotools/calendarwrapper.hxx20
-rw-r--r--include/unotools/charclass.hxx30
-rw-r--r--include/unotools/closeveto.hxx2
-rw-r--r--include/unotools/cmdoptions.hxx2
-rw-r--r--include/unotools/collatorwrapper.hxx21
-rw-r--r--include/unotools/compatibility.hxx2
-rw-r--r--include/unotools/configitem.hxx50
-rw-r--r--include/unotools/configmgr.hxx6
-rw-r--r--include/unotools/confignode.hxx45
-rw-r--r--include/unotools/configvaluecontainer.hxx4
-rw-r--r--include/unotools/digitgroupingiterator.hxx12
-rw-r--r--include/unotools/dynamicmenuoptions.hxx2
-rw-r--r--include/unotools/eventcfg.hxx16
-rw-r--r--include/unotools/eventlisteneradapter.hxx6
-rw-r--r--include/unotools/fltrcfg.hxx4
-rw-r--r--include/unotools/fontcfg.hxx20
-rw-r--r--include/unotools/historyoptions.hxx2
-rw-r--r--include/unotools/intlwrapper.hxx4
-rw-r--r--include/unotools/lingucfg.hxx38
-rw-r--r--include/unotools/localedatawrapper.hxx104
-rw-r--r--include/unotools/localfilehelper.hxx2
-rw-r--r--include/unotools/mediadescriptor.hxx16
-rw-r--r--include/unotools/moduleoptions.hxx6
-rw-r--r--include/unotools/nativenumberwrapper.hxx12
-rw-r--r--include/unotools/numberformatcodewrapper.hxx16
-rw-r--r--include/unotools/progresshandlerwrap.hxx16
-rw-r--r--include/unotools/securityoptions.hxx10
-rw-r--r--include/unotools/sharedunocomponent.hxx79
-rw-r--r--include/unotools/textsearch.hxx20
-rw-r--r--include/unotools/transliterationwrapper.hxx10
-rw-r--r--include/unotools/ucbhelper.hxx6
-rw-r--r--include/unotools/ucbstreamhelper.hxx10
-rw-r--r--include/unotools/viewoptions.hxx10
-rw-r--r--include/unotools/xmlaccelcfg.hxx32
36 files changed, 337 insertions, 356 deletions
diff --git a/include/unotools/accessiblerelationsethelper.hxx b/include/unotools/accessiblerelationsethelper.hxx
index 33e3a88f6f06..f71872b9ed77 100644
--- a/include/unotools/accessiblerelationsethelper.hxx
+++ b/include/unotools/accessiblerelationsethelper.hxx
@@ -45,9 +45,7 @@ namespace utl
<code>AccessibleRelationSet</code> service.
*/
class UNOTOOLS_DLLPUBLIC AccessibleRelationSetHelper
- : public cppu::WeakImplHelper1<
- ::com::sun::star::accessibility::XAccessibleRelationSet
- >
+ : public cppu::WeakImplHelper1< css::accessibility::XAccessibleRelationSet >
{
public:
//===== internal ========================================================
@@ -65,7 +63,7 @@ public:
Returns the number of relations or zero if there are none.
*/
virtual sal_Int32 SAL_CALL getRelationCount( )
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Returns the relation of this relation set that is specified by
the given index.
@@ -80,10 +78,10 @@ public:
has the type INVALID.
*/
- virtual ::com::sun::star::accessibility::AccessibleRelation SAL_CALL
+ virtual css::accessibility::AccessibleRelation SAL_CALL
getRelation( sal_Int32 nIndex )
- throw (::com::sun::star::lang::IndexOutOfBoundsException,
- ::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::lang::IndexOutOfBoundsException,
+ css::uno::RuntimeException, std::exception) override;
/** Tests whether the relation set contains a relation matching the
specified key.
@@ -98,7 +96,7 @@ public:
given type and <FALSE/> if there is no such relation in the set.
*/
virtual sal_Bool SAL_CALL containsRelation( sal_Int16 aRelationType )
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Retrieve and return the relation with the given relation type.
@@ -111,27 +109,27 @@ public:
of) this relation is returned. Otherwise a relation with the
type INVALID is returned.
*/
- virtual ::com::sun::star::accessibility::AccessibleRelation SAL_CALL
+ virtual css::accessibility::AccessibleRelation SAL_CALL
getRelationByType( sal_Int16 aRelationType )
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
void AddRelation(
- const ::com::sun::star::accessibility::AccessibleRelation& rRelation)
- throw (::com::sun::star::uno::RuntimeException);
+ const css::accessibility::AccessibleRelation& rRelation)
+ throw (css::uno::RuntimeException);
//===== XTypeProvider ===================================================
/** Returns a sequence of all supported interfaces.
*/
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type> SAL_CALL
+ virtual css::uno::Sequence< css::uno::Type> SAL_CALL
getTypes()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Returns a implementation id.
*/
- virtual ::com::sun::star::uno::Sequence<sal_Int8> SAL_CALL
+ virtual css::uno::Sequence<sal_Int8> SAL_CALL
getImplementationId()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
protected:
/// Mutex guarding this object.
diff --git a/include/unotools/accessiblestatesethelper.hxx b/include/unotools/accessiblestatesethelper.hxx
index 0417a601295b..7d5accac0e6f 100644
--- a/include/unotools/accessiblestatesethelper.hxx
+++ b/include/unotools/accessiblestatesethelper.hxx
@@ -44,9 +44,7 @@ namespace utl
<code>AccessibleStateSet</code> service.
*/
class UNOTOOLS_DLLPUBLIC AccessibleStateSetHelper
- : public cppu::WeakImplHelper1<
- ::com::sun::star::accessibility::XAccessibleStateSet
- >
+ : public cppu::WeakImplHelper1< css::accessibility::XAccessibleStateSet >
{
public:
//===== internal ========================================================
@@ -77,7 +75,7 @@ public:
<FALSE/> if there is at least one state set in it.
*/
virtual sal_Bool SAL_CALL isEmpty ()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Checks if the given state is a member of the state set of this
object.
@@ -91,7 +89,7 @@ public:
state set and <FALSE/> otherwise.
*/
virtual sal_Bool SAL_CALL contains (sal_Int16 aState)
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Checks if all of the given states are in this object's state
set.
@@ -109,37 +107,37 @@ public:
object's state set.
*/
virtual sal_Bool SAL_CALL containsAll (
- const ::com::sun::star::uno::Sequence<sal_Int16>& rStateSet)
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ const css::uno::Sequence<sal_Int16>& rStateSet)
+ throw (css::uno::RuntimeException, std::exception) override;
/** Returns a sequence of all states.
*/
- virtual com::sun::star::uno::Sequence<sal_Int16> SAL_CALL getStates()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Sequence<sal_Int16> SAL_CALL getStates()
+ throw (css::uno::RuntimeException, std::exception) override;
/** Adds a state to the set.
*/
void AddState(sal_Int16 aState)
- throw (::com::sun::star::uno::RuntimeException);
+ throw (css::uno::RuntimeException);
/** Removes a state from the set if the set contains the state, otherwise nothing is done.
*/
void RemoveState(sal_Int16 aState)
- throw (::com::sun::star::uno::RuntimeException);
+ throw (css::uno::RuntimeException);
//===== XTypeProvider ===================================================
/** Returns a sequence of all supported interfaces.
*/
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type> SAL_CALL
+ virtual css::uno::Sequence< css::uno::Type> SAL_CALL
getTypes()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Returns a implementation id.
*/
- virtual ::com::sun::star::uno::Sequence<sal_Int8> SAL_CALL
+ virtual css::uno::Sequence<sal_Int8> SAL_CALL
getImplementationId()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
protected:
/// Mutex guarding this object.
diff --git a/include/unotools/calendarwrapper.hxx b/include/unotools/calendarwrapper.hxx
index ceffdea6b607..cd4f63509bba 100644
--- a/include/unotools/calendarwrapper.hxx
+++ b/include/unotools/calendarwrapper.hxx
@@ -41,21 +41,21 @@ namespace com { namespace sun { namespace star {
class UNOTOOLS_DLLPUBLIC CalendarWrapper
{
- ::com::sun::star::uno::Reference< ::com::sun::star::i18n::XCalendar4 > xC;
+ css::uno::Reference< css::i18n::XCalendar4 > xC;
DateTime aEpochStart; // 1Jan1970
public:
CalendarWrapper(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > & rxContext
+ const css::uno::Reference< css::uno::XComponentContext > & rxContext
);
~CalendarWrapper();
// wrapper implementations of XCalendar
- void loadDefaultCalendar( const ::com::sun::star::lang::Locale& rLocale );
- void loadCalendar( const OUString& rUniqueID, const ::com::sun::star::lang::Locale& rLocale );
- ::com::sun::star::uno::Sequence< OUString > getAllCalendars( const ::com::sun::star::lang::Locale& rLocale ) const;
+ void loadDefaultCalendar( const css::lang::Locale& rLocale );
+ void loadCalendar( const OUString& rUniqueID, const css::lang::Locale& rLocale );
+ css::uno::Sequence< OUString > getAllCalendars( const css::lang::Locale& rLocale ) const;
OUString getUniqueID() const;
/// set UTC date/time
void setDateTime( double fTimeInDays );
@@ -82,11 +82,11 @@ public:
// wrapper implementations of XCalendar3
- ::com::sun::star::i18n::Calendar2 getLoadedCalendar() const;
- ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > getDays() const;
- ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > getMonths() const;
- ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > getGenitiveMonths() const;
- ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > getPartitiveMonths() const;
+ css::i18n::Calendar2 getLoadedCalendar() const;
+ css::uno::Sequence< css::i18n::CalendarItem2 > getDays() const;
+ css::uno::Sequence< css::i18n::CalendarItem2 > getMonths() const;
+ css::uno::Sequence< css::i18n::CalendarItem2 > getGenitiveMonths() const;
+ css::uno::Sequence< css::i18n::CalendarItem2 > getPartitiveMonths() const;
// wrapper implementations of XCalendar4
diff --git a/include/unotools/charclass.hxx b/include/unotools/charclass.hxx
index cdf9d0716794..32092dcffc04 100644
--- a/include/unotools/charclass.hxx
+++ b/include/unotools/charclass.hxx
@@ -38,35 +38,35 @@ namespace com { namespace sun { namespace star {
}}}
const sal_Int32 nCharClassAlphaType =
- ::com::sun::star::i18n::KCharacterType::UPPER |
- ::com::sun::star::i18n::KCharacterType::LOWER |
- ::com::sun::star::i18n::KCharacterType::TITLE_CASE;
+ css::i18n::KCharacterType::UPPER |
+ css::i18n::KCharacterType::LOWER |
+ css::i18n::KCharacterType::TITLE_CASE;
const sal_Int32 nCharClassAlphaTypeMask =
nCharClassAlphaType |
- ::com::sun::star::i18n::KCharacterType::PRINTABLE |
- ::com::sun::star::i18n::KCharacterType::BASE_FORM;
+ css::i18n::KCharacterType::PRINTABLE |
+ css::i18n::KCharacterType::BASE_FORM;
const sal_Int32 nCharClassLetterType =
nCharClassAlphaType |
- ::com::sun::star::i18n::KCharacterType::LETTER;
+ css::i18n::KCharacterType::LETTER;
const sal_Int32 nCharClassLetterTypeMask =
nCharClassAlphaTypeMask |
- ::com::sun::star::i18n::KCharacterType::LETTER;
+ css::i18n::KCharacterType::LETTER;
const sal_Int32 nCharClassNumericType =
- ::com::sun::star::i18n::KCharacterType::DIGIT;
+ css::i18n::KCharacterType::DIGIT;
const sal_Int32 nCharClassNumericTypeMask =
nCharClassNumericType |
- ::com::sun::star::i18n::KCharacterType::PRINTABLE |
- ::com::sun::star::i18n::KCharacterType::BASE_FORM;
+ css::i18n::KCharacterType::PRINTABLE |
+ css::i18n::KCharacterType::BASE_FORM;
class UNOTOOLS_DLLPUBLIC CharClass
{
LanguageTag maLanguageTag;
- ::com::sun::star::uno::Reference< ::com::sun::star::i18n::XCharacterClassification > xCC;
+ css::uno::Reference< css::i18n::XCharacterClassification > xCC;
mutable ::osl::Mutex aMutex;
CharClass(const CharClass&) = delete;
@@ -75,7 +75,7 @@ class UNOTOOLS_DLLPUBLIC CharClass
public:
/// Preferred ctor with service manager specified
CharClass(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > & rxContext,
+ const css::uno::Reference< css::uno::XComponentContext > & rxContext,
const LanguageTag& rLanguageTag );
/// Deprecated ctor, tries to get a process service manager or to load the
@@ -153,7 +153,7 @@ public:
sal_Int32 getCharacterType( const OUString& rStr, sal_Int32 nPos ) const;
sal_Int32 getStringType( const OUString& rStr, sal_Int32 nPos, sal_Int32 nCount ) const;
- ::com::sun::star::i18n::ParseResult parseAnyToken(
+ css::i18n::ParseResult parseAnyToken(
const OUString& rStr,
sal_Int32 nPos,
sal_Int32 nStartCharFlags,
@@ -161,7 +161,7 @@ public:
sal_Int32 nContCharFlags,
const OUString& userDefinedCharactersCont ) const;
- ::com::sun::star::i18n::ParseResult parsePredefinedToken(
+ css::i18n::ParseResult parsePredefinedToken(
sal_Int32 nTokenType,
const OUString& rStr,
sal_Int32 nPos,
@@ -183,7 +183,7 @@ public:
private:
- const ::com::sun::star::lang::Locale & getMyLocale() const;
+ const css::lang::Locale & getMyLocale() const;
};
#endif // INCLUDED_UNOTOOLS_CHARCLASS_HXX
diff --git a/include/unotools/closeveto.hxx b/include/unotools/closeveto.hxx
index fe5521618a71..5c5adc5ac3e3 100644
--- a/include/unotools/closeveto.hxx
+++ b/include/unotools/closeveto.hxx
@@ -38,7 +38,7 @@ namespace utl
class UNOTOOLS_DLLPUBLIC CloseVeto
{
public:
- CloseVeto( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& i_closeable,
+ CloseVeto( const css::uno::Reference< css::uno::XInterface >& i_closeable,
bool bHasOwnership = false);
~CloseVeto();
diff --git a/include/unotools/cmdoptions.hxx b/include/unotools/cmdoptions.hxx
index cdc57765e263..b5216afd2f86 100644
--- a/include/unotools/cmdoptions.hxx
+++ b/include/unotools/cmdoptions.hxx
@@ -107,7 +107,7 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtCommandOptions : public utl::detail:
notified, if configuration was changed.
*//*-*****************************************************************************************************/
- void EstablisFrameCallback(const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& xFrame);
+ void EstablisFrameCallback(const css::uno::Reference< css::frame::XFrame >& xFrame);
private:
diff --git a/include/unotools/collatorwrapper.hxx b/include/unotools/collatorwrapper.hxx
index e1fe3edba13e..a644f3899a48 100644
--- a/include/unotools/collatorwrapper.hxx
+++ b/include/unotools/collatorwrapper.hxx
@@ -30,20 +30,13 @@ namespace com { namespace sun { namespace star { namespace uno {
class UNOTOOLS_DLLPUBLIC CollatorWrapper
{
private:
-
- ::com::sun::star::uno::Reference<
- ::com::sun::star::uno::XComponentContext
- > mxServiceFactory;
-
- ::com::sun::star::uno::Reference<
- ::com::sun::star::i18n::XCollator
- > mxInternationalCollator;
+ css::uno::Reference< css::uno::XComponentContext > mxServiceFactory;
+ css::uno::Reference< css::i18n::XCollator > mxInternationalCollator;
public:
CollatorWrapper (
- const ::com::sun::star::uno::Reference<
- ::com::sun::star::uno::XComponentContext > &rxContext);
+ const css::uno::Reference< css::uno::XComponentContext > &rxContext);
~CollatorWrapper();
@@ -51,18 +44,18 @@ class UNOTOOLS_DLLPUBLIC CollatorWrapper
compareString (
const OUString& s1, const OUString& s2) const;
- ::com::sun::star::uno::Sequence< OUString >
+ css::uno::Sequence< OUString >
listCollatorAlgorithms (
- const ::com::sun::star::lang::Locale& rLocale) const;
+ const css::lang::Locale& rLocale) const;
sal_Int32
loadDefaultCollator (
- const ::com::sun::star::lang::Locale& rLocale, sal_Int32 nOption);
+ const css::lang::Locale& rLocale, sal_Int32 nOption);
sal_Int32
loadCollatorAlgorithm (
const OUString& rAlgorithm,
- const ::com::sun::star::lang::Locale& rLocale, sal_Int32 nOption);
+ const css::lang::Locale& rLocale, sal_Int32 nOption);
protected:
diff --git a/include/unotools/compatibility.hxx b/include/unotools/compatibility.hxx
index 60bde91fcee0..554f51ed6e78 100644
--- a/include/unotools/compatibility.hxx
+++ b/include/unotools/compatibility.hxx
@@ -123,7 +123,7 @@ class UNOTOOLS_DLLPUBLIC SvtCompatibilityOptions: public utl::detail::Options
@onerror We return an empty list.
*//*-*****************************************************************************************************/
- ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > > GetList() const;
+ css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > > GetList() const;
/*-****************************************************************************************************
@short append a new item
diff --git a/include/unotools/configitem.hxx b/include/unotools/configitem.hxx
index 9d5e4ba8afd0..b7be7fe42d17 100644
--- a/include/unotools/configitem.hxx
+++ b/include/unotools/configitem.hxx
@@ -77,9 +77,9 @@ namespace utl
friend class ConfigManager;
const OUString sSubTree;
- com::sun::star::uno::Reference< com::sun::star::container::XHierarchicalNameAccess>
+ css::uno::Reference< css::container::XHierarchicalNameAccess>
m_xHierarchyAccess;
- com::sun::star::uno::Reference< com::sun::star::util::XChangesListener >
+ css::uno::Reference< css::util::XChangesListener >
xChangeLstnr;
ConfigItemMode m_nMode;
bool m_bIsModified;
@@ -88,7 +88,7 @@ namespace utl
void RemoveChangesListener();
void CallNotify(
- const com::sun::star::uno::Sequence<OUString>& aPropertyNames);
+ const css::uno::Sequence<OUString>& aPropertyNames);
// In special mode ALL_LOCALES we must support reading/writing of localized cfg entries as Sequence< PropertyValue >.
// These methods are helper to convert given lists of names and Any-values.
@@ -100,15 +100,15 @@ namespace utl
// LOCALE VALUE
// "de" "Mein Name"
// "en-US" "my name"
- void impl_packLocalizedProperties ( const com::sun::star::uno::Sequence< OUString >& lInNames ,
- const com::sun::star::uno::Sequence< com::sun::star::uno::Any >& lInValues ,
- com::sun::star::uno::Sequence< com::sun::star::uno::Any >& lOutValues );
- void impl_unpackLocalizedProperties ( const com::sun::star::uno::Sequence< OUString >& lInNames ,
- const com::sun::star::uno::Sequence< com::sun::star::uno::Any >& lInValues ,
- com::sun::star::uno::Sequence< OUString >& lOutNames ,
- com::sun::star::uno::Sequence< com::sun::star::uno::Any >& lOutValues );
-
- com::sun::star::uno::Reference< com::sun::star::container::XHierarchicalNameAccess>
+ void impl_packLocalizedProperties ( const css::uno::Sequence< OUString >& lInNames ,
+ const css::uno::Sequence< css::uno::Any >& lInValues ,
+ css::uno::Sequence< css::uno::Any >& lOutValues );
+ void impl_unpackLocalizedProperties ( const css::uno::Sequence< OUString >& lInNames ,
+ const css::uno::Sequence< css::uno::Any >& lInValues ,
+ css::uno::Sequence< OUString >& lOutNames ,
+ css::uno::Sequence< css::uno::Any >& lOutValues );
+
+ css::uno::Reference< css::container::XHierarchicalNameAccess>
GetTree();
/** writes the changed values into the sub tree.
Private and only called from non-virtual public Commit(). */
@@ -121,15 +121,15 @@ namespace utl
void SetModified (); // mark item as modified
void ClearModified(); // reset state after commit!
- com::sun::star::uno::Sequence< com::sun::star::uno::Any>
- GetProperties(const com::sun::star::uno::Sequence< OUString >& rNames);
+ css::uno::Sequence< css::uno::Any>
+ GetProperties(const css::uno::Sequence< OUString >& rNames);
- com::sun::star::uno::Sequence< sal_Bool >
- GetReadOnlyStates(const com::sun::star::uno::Sequence< OUString >& rNames);
+ css::uno::Sequence< sal_Bool >
+ GetReadOnlyStates(const css::uno::Sequence< OUString >& rNames);
bool PutProperties(
- const com::sun::star::uno::Sequence< OUString >& rNames,
- const com::sun::star::uno::Sequence< com::sun::star::uno::Any>& rValues);
+ const css::uno::Sequence< OUString >& rNames,
+ const css::uno::Sequence< css::uno::Any>& rValues);
/** enables notifications about changes on selected sub nodes/values
@@ -139,7 +139,7 @@ namespace utl
@see Notify
@see DisableNotification
*/
- bool EnableNotification(const com::sun::star::uno::Sequence< OUString >& rNames,
+ bool EnableNotification(const css::uno::Sequence< OUString >& rNames,
bool bEnableInternalNotification = false);
/** disables notifications about changes on sub nodes/values, which previosly had
been enabled with EnableNotification
@@ -149,20 +149,20 @@ namespace utl
void DisableNotification();
//returns all members of a node in a specific format
- com::sun::star::uno::Sequence< OUString >
+ css::uno::Sequence< OUString >
GetNodeNames(const OUString& rNode);
//returns all members of a node in a specific format
- com::sun::star::uno::Sequence< OUString >
+ css::uno::Sequence< OUString >
GetNodeNames(const OUString& rNode, ConfigNameFormat eFormat);
// remove all members of a set
bool ClearNodeSet(const OUString& rNode);
// remove selected members of a set
bool ClearNodeElements(const OUString& rNode,
- com::sun::star::uno::Sequence< OUString >& rElements);
+ css::uno::Sequence< OUString >& rElements);
// change or add members to a set
- bool SetSetProperties(const OUString& rNode, const com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue >& rValues);
+ bool SetSetProperties(const OUString& rNode, const css::uno::Sequence< css::beans::PropertyValue >& rValues);
// remove, change or add members of a set
- bool ReplaceSetProperties(const OUString& rNode, const com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue >& rValues);
+ bool ReplaceSetProperties(const OUString& rNode, const css::uno::Sequence< css::beans::PropertyValue >& rValues);
// add a new node without setting any properties
bool AddNode(const OUString& rNode, const OUString& rNewNode);
@@ -171,7 +171,7 @@ namespace utl
/** is called from the ConfigManager before application ends of from the
PropertyChangeListener if the sub tree broadcasts changes. */
- virtual void Notify( const com::sun::star::uno::Sequence<OUString>& aPropertyNames)=0;
+ virtual void Notify( const css::uno::Sequence<OUString>& aPropertyNames)=0;
const OUString& GetSubTreeName() const {return sSubTree;}
diff --git a/include/unotools/configmgr.hxx b/include/unotools/configmgr.hxx
index 92ae409b3882..bf425885b083 100644
--- a/include/unotools/configmgr.hxx
+++ b/include/unotools/configmgr.hxx
@@ -57,16 +57,14 @@ public:
SAL_DLLPRIVATE static ConfigManager & getConfigManager();
- SAL_DLLPRIVATE static com::sun::star::uno::Reference<
- com::sun::star::container::XHierarchicalNameAccess>
+ SAL_DLLPRIVATE static css::uno::Reference< css::container::XHierarchicalNameAccess>
acquireTree(utl::ConfigItem & item);
SAL_DLLPRIVATE ConfigManager();
SAL_DLLPRIVATE ~ConfigManager();
- SAL_DLLPRIVATE com::sun::star::uno::Reference<
- com::sun::star::container::XHierarchicalNameAccess >
+ SAL_DLLPRIVATE css::uno::Reference< css::container::XHierarchicalNameAccess >
addConfigItem(utl::ConfigItem & item);
SAL_DLLPRIVATE void removeConfigItem(utl::ConfigItem & item);
diff --git a/include/unotools/confignode.hxx b/include/unotools/confignode.hxx
index ea088c4faafd..9fcde9f4a602 100644
--- a/include/unotools/confignode.hxx
+++ b/include/unotools/confignode.hxx
@@ -46,30 +46,29 @@ namespace utl
class UNOTOOLS_DLLPUBLIC OConfigurationNode : public ::utl::OEventListenerAdapter
{
private:
- ::com::sun::star::uno::Reference< ::com::sun::star::container::XHierarchicalNameAccess >
+ css::uno::Reference< css::container::XHierarchicalNameAccess >
m_xHierarchyAccess; /// accessing children grandchildren (mandatory interface of our UNO object)
- ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess >
+ css::uno::Reference< css::container::XNameAccess >
m_xDirectAccess; /// accessing children (mandatory interface of our UNO object)
- ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameReplace >
+ css::uno::Reference< css::container::XNameReplace >
m_xReplaceAccess; /// replacing child values
- ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameContainer >
+ css::uno::Reference< css::container::XNameContainer >
m_xContainerAccess; /// modifying set nodes (optional interface of our UNO object)
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >
+ css::uno::Reference< css::uno::XInterface >
m_xDummy;
- bool m_bEscapeNames; /// escape names before accessing children ?
+ bool m_bEscapeNames; /// escape names before accessing children ?
- OUString
- m_sCompletePath;
+ OUString m_sCompletePath;
- OConfigurationNode insertNode(const OUString& _rName,const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _xNode) const throw();
+ OConfigurationNode insertNode(const OUString& _rName,const css::uno::Reference< css::uno::XInterface >& _xNode) const throw();
protected:
/// constructs a node object with an interface representing a node
OConfigurationNode(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxNode
+ const css::uno::Reference< css::uno::XInterface >& _rxNode
);
- const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess >&
+ const css::uno::Reference< css::container::XNameAccess >&
getUNONode() const { return m_xDirectAccess; }
public:
@@ -124,11 +123,9 @@ namespace utl
Unfortunately, this implies that if a void value is returned, you won't have a clue if this means
"the path does not exist" (besides the assertion made :), or if the value is really void.
*/
- ::com::sun::star::uno::Any
- getNodeValue(const OUString& _rPath) const throw();
+ css::uno::Any getNodeValue(const OUString& _rPath) const throw();
- ::com::sun::star::uno::Any
- getNodeValue( const sal_Char* _pAsciiPath ) const
+ css::uno::Any getNodeValue( const sal_Char* _pAsciiPath ) const
{
return getNodeValue( OUString::createFromAscii( _pAsciiPath ) );
}
@@ -139,15 +136,15 @@ namespace utl
node.
@return sal_True if and only if the write was successful.
*/
- bool setNodeValue(const OUString& _rPath, const ::com::sun::star::uno::Any& _rValue) const throw();
+ bool setNodeValue(const OUString& _rPath, const css::uno::Any& _rValue) const throw();
- bool setNodeValue( const sal_Char* _pAsciiPath, const ::com::sun::star::uno::Any& _rValue ) const
+ bool setNodeValue( const sal_Char* _pAsciiPath, const css::uno::Any& _rValue ) const
{
return setNodeValue( OUString::createFromAscii( _pAsciiPath ), _rValue );
}
/// return the names of the existing children
- ::com::sun::star::uno::Sequence< OUString >
+ css::uno::Sequence< OUString >
getNodeNames() const throw();
/** enables or disables name escaping when accessing direct children<p/>
@@ -185,7 +182,7 @@ namespace utl
protected:
// OEventListenerAdapter
- virtual void _disposing( const ::com::sun::star::lang::EventObject& _rSource ) override;
+ virtual void _disposing( const css::lang::EventObject& _rSource ) override;
protected:
enum NAMEORIGIN
@@ -205,13 +202,13 @@ namespace utl
*/
class UNOTOOLS_DLLPUBLIC OConfigurationTreeRoot : public OConfigurationNode
{
- ::com::sun::star::uno::Reference< ::com::sun::star::util::XChangesBatch >
+ css::uno::Reference< css::util::XChangesBatch >
m_xCommitter;
protected:
/** ctor for a readonly node
*/
OConfigurationTreeRoot(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxRootNode
+ const css::uno::Reference< css::uno::XInterface >& _rxRootNode
);
public:
@@ -258,7 +255,7 @@ namespace utl
@see createWithServiceFactory
*/
static OConfigurationTreeRoot createWithProvider(
- const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& _rxConfProvider,
+ const css::uno::Reference< css::lang::XMultiServiceFactory >& _rxConfProvider,
const OUString& _rPath,
sal_Int32 _nDepth = -1,
CREATION_MODE _eMode = CM_UPDATABLE,
@@ -277,7 +274,7 @@ namespace utl
@param _nDepth depth for node retrieval
@param _eMode specifies which privileges should be applied when retrieving the node
*/
- static OConfigurationTreeRoot createWithComponentContext(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& _rxContext,
+ static OConfigurationTreeRoot createWithComponentContext(const css::uno::Reference< css::uno::XComponentContext >& _rxContext,
const OUString& _rPath, sal_Int32 _nDepth = -1, CREATION_MODE _eMode = CM_UPDATABLE, bool _bLazyWrite = true);
/** tolerant version of the <member>createWithServiceFactory</member>
@@ -286,7 +283,7 @@ namespace utl
the configuration could be initialized, errors in the creation of the specific node (e.g. because the
given node path does not exist) are still asserted.</p>
*/
- static OConfigurationTreeRoot tryCreateWithComponentContext( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rxContext,
+ static OConfigurationTreeRoot tryCreateWithComponentContext( const css::uno::Reference< css::uno::XComponentContext >& rxContext,
const OUString& _rPath, sal_Int32 _nDepth = -1, CREATION_MODE _eMode = CM_UPDATABLE, bool _bLazyWrite = true );
/** commit all changes made on the subtree the object is the root for<p/>
diff --git a/include/unotools/configvaluecontainer.hxx b/include/unotools/configvaluecontainer.hxx
index 0104e66b98b7..a481c65548b1 100644
--- a/include/unotools/configvaluecontainer.hxx
+++ b/include/unotools/configvaluecontainer.hxx
@@ -89,7 +89,7 @@ namespace utl
specifies the number of levels to access under the node given by <arg>_pConfigLocation</arg>
*/
OConfigurationValueContainer(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& _rxORB,
+ const css::uno::Reference< css::uno::XComponentContext >& _rxORB,
::osl::Mutex& _rAccessSafety,
const sal_Char* _pConfigLocation,
const CVCFlags _nAccessFlags = CVCFlags::UPDATE_ACCESS | CVCFlags::LAZY_UPDATE,
@@ -116,7 +116,7 @@ namespace utl
void registerExchangeLocation(
const sal_Char* _pRelativePathAscii,
void* _pContainer,
- const ::com::sun::star::uno::Type& _rValueType
+ const css::uno::Type& _rValueType
);
public:
diff --git a/include/unotools/digitgroupingiterator.hxx b/include/unotools/digitgroupingiterator.hxx
index 12f8dc163b3d..c6eaf1cafb99 100644
--- a/include/unotools/digitgroupingiterator.hxx
+++ b/include/unotools/digitgroupingiterator.hxx
@@ -60,7 +60,7 @@ namespace utl {
class DigitGroupingIterator
{
- const ::com::sun::star::uno::Sequence< sal_Int32 > maGroupings;
+ const css::uno::Sequence< sal_Int32 > maGroupings;
sal_Int32 mnGroup; // current active grouping
sal_Int32 mnDigits; // current active digits per group
@@ -121,7 +121,7 @@ class DigitGroupingIterator
public:
- explicit DigitGroupingIterator( const ::com::sun::star::uno::Sequence< sal_Int32 > & rGroupings )
+ explicit DigitGroupingIterator( const css::uno::Sequence< sal_Int32 > & rGroupings )
: maGroupings( rGroupings)
{
initGrouping();
@@ -164,14 +164,14 @@ public:
digit. For example, for grouping in thousands and nIntegerDigits==7 the
sequence returned would be {1,0,0,1,0,0,0} so the caller would add a
separator after the 1st and the 4th digit. */
- static ::com::sun::star::uno::Sequence< sal_Bool > createForwardSequence(
+ static css::uno::Sequence< sal_Bool > createForwardSequence(
sal_Int32 nIntegerDigits,
- const ::com::sun::star::uno::Sequence< sal_Int32 > & rGroupings )
+ const css::uno::Sequence< sal_Int32 > & rGroupings )
{
if (nIntegerDigits <= 0)
- return ::com::sun::star::uno::Sequence< sal_Bool >();
+ return css::uno::Sequence< sal_Bool >();
DigitGroupingIterator aIterator( rGroupings);
- ::com::sun::star::uno::Sequence< sal_Bool > aSeq( nIntegerDigits);
+ css::uno::Sequence< sal_Bool > aSeq( nIntegerDigits);
sal_Bool* pArr = aSeq.getArray();
for (sal_Int32 j = 0; --nIntegerDigits >= 0; ++j)
{
diff --git a/include/unotools/dynamicmenuoptions.hxx b/include/unotools/dynamicmenuoptions.hxx
index 9e3aef3d5b77..4b04a40521a3 100644
--- a/include/unotools/dynamicmenuoptions.hxx
+++ b/include/unotools/dynamicmenuoptions.hxx
@@ -87,7 +87,7 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtDynamicMenuOptions : public utl::det
@onerror We return an empty list.
*//*-*****************************************************************************************************/
- ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > > GetMenu( EDynamicMenuType eMenu ) const;
+ css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > > GetMenu( EDynamicMenuType eMenu ) const;
private:
/*-****************************************************************************************************
diff --git a/include/unotools/eventcfg.hxx b/include/unotools/eventcfg.hxx
index 38a38b880452..cfe6026d03af 100644
--- a/include/unotools/eventcfg.hxx
+++ b/include/unotools/eventcfg.hxx
@@ -65,20 +65,20 @@ enum class GlobalEventId
class GlobalEventConfig_Impl;
class UNOTOOLS_DLLPUBLIC GlobalEventConfig:
- public ::cppu::WeakImplHelper2 < ::com::sun::star::document::XEventsSupplier, ::com::sun::star::container::XNameReplace >
+ public ::cppu::WeakImplHelper2 < css::document::XEventsSupplier, css::container::XNameReplace >
{
public:
GlobalEventConfig( );
virtual ~GlobalEventConfig( );
static ::osl::Mutex& GetOwnStaticMutex();
- ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameReplace > SAL_CALL getEvents( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- void SAL_CALL replaceByName( const OUString& aName, const ::com::sun::star::uno::Any& aElement ) throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::container::NoSuchElementException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- ::com::sun::star::uno::Any SAL_CALL getByName( const OUString& aName ) throw (::com::sun::star::container::NoSuchElementException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- ::com::sun::star::uno::Sequence< OUString > SAL_CALL getElementNames( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- sal_Bool SAL_CALL hasByName( const OUString& aName ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- ::com::sun::star::uno::Type SAL_CALL getElementType( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- sal_Bool SAL_CALL hasElements( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ css::uno::Reference< css::container::XNameReplace > SAL_CALL getEvents( ) throw (css::uno::RuntimeException, std::exception) override;
+ void SAL_CALL replaceByName( const OUString& aName, const css::uno::Any& aElement ) throw (css::lang::IllegalArgumentException, css::container::NoSuchElementException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override;
+ css::uno::Any SAL_CALL getByName( const OUString& aName ) throw (css::container::NoSuchElementException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override;
+ css::uno::Sequence< OUString > SAL_CALL getElementNames( ) throw (css::uno::RuntimeException, std::exception) override;
+ sal_Bool SAL_CALL hasByName( const OUString& aName ) throw (css::uno::RuntimeException, std::exception) override;
+ css::uno::Type SAL_CALL getElementType( ) throw (css::uno::RuntimeException, std::exception) override;
+ sal_Bool SAL_CALL hasElements( ) throw (css::uno::RuntimeException, std::exception) override;
static OUString GetEventName( GlobalEventId nID );
private:
diff --git a/include/unotools/eventlisteneradapter.hxx b/include/unotools/eventlisteneradapter.hxx
index 26c1ef45dba4..78408ed2b46b 100644
--- a/include/unotools/eventlisteneradapter.hxx
+++ b/include/unotools/eventlisteneradapter.hxx
@@ -46,11 +46,11 @@ namespace utl
OEventListenerAdapter();
virtual ~OEventListenerAdapter();
- void startComponentListening( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XComponent >& _rxComp );
- void stopComponentListening( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XComponent >& _rxComp );
+ void startComponentListening( const css::uno::Reference< css::lang::XComponent >& _rxComp );
+ void stopComponentListening( const css::uno::Reference< css::lang::XComponent >& _rxComp );
void stopAllComponentListening( );
- virtual void _disposing( const ::com::sun::star::lang::EventObject& _rSource ) = 0;
+ virtual void _disposing( const css::lang::EventObject& _rSource ) = 0;
};
} // namespace utl
diff --git a/include/unotools/fltrcfg.hxx b/include/unotools/fltrcfg.hxx
index b1aa2f8ab2b0..ceb4d9764636 100644
--- a/include/unotools/fltrcfg.hxx
+++ b/include/unotools/fltrcfg.hxx
@@ -28,7 +28,7 @@ class UNOTOOLS_DLLPUBLIC SvtFilterOptions : public utl::ConfigItem
private:
SvtFilterOptions_Impl* pImp;
- const com::sun::star::uno::Sequence<OUString>& GetPropertyNames();
+ const css::uno::Sequence<OUString>& GetPropertyNames();
virtual void ImplCommit() override;
@@ -36,7 +36,7 @@ public:
SvtFilterOptions();
virtual ~SvtFilterOptions();
- virtual void Notify( const com::sun::star::uno::Sequence<OUString>& aPropertyNames) override;
+ virtual void Notify( const css::uno::Sequence<OUString>& aPropertyNames) override;
void Load();
void SetLoadWordBasicCode( bool bFlag );
diff --git a/include/unotools/fontcfg.hxx b/include/unotools/fontcfg.hxx
index c13e4a5a4138..a37242932dfa 100644
--- a/include/unotools/fontcfg.hxx
+++ b/include/unotools/fontcfg.hxx
@@ -94,9 +94,9 @@ namespace utl
class UNOTOOLS_DLLPUBLIC DefaultFontConfiguration
{
- com::sun::star::uno::Reference< com::sun::star::lang::XMultiServiceFactory >
+ css::uno::Reference< css::lang::XMultiServiceFactory >
m_xConfigProvider;
- com::sun::star::uno::Reference< com::sun::star::container::XNameAccess >
+ css::uno::Reference< css::container::XNameAccess >
m_xConfigAccess;
struct LocaleAccess
@@ -105,7 +105,7 @@ class UNOTOOLS_DLLPUBLIC DefaultFontConfiguration
// used to get rid of upper/lower case problems
OUString aConfigLocaleString;
// xAccess is mutable to be able to be filled on demand
- mutable com::sun::star::uno::Reference< com::sun::star::container::XNameAccess > xAccess;
+ mutable css::uno::Reference< css::container::XNameAccess > xAccess;
};
std::unordered_map< OUString, LocaleAccess, OUStringHash > m_aConfig;
@@ -137,13 +137,13 @@ struct UNOTOOLS_DLLPUBLIC FontNameAttr
class UNOTOOLS_DLLPUBLIC FontSubstConfiguration
{
private:
- com::sun::star::uno::Reference< com::sun::star::lang::XMultiServiceFactory >
+ css::uno::Reference< css::lang::XMultiServiceFactory >
m_xConfigProvider;
- com::sun::star::uno::Reference< com::sun::star::container::XNameAccess >
+ css::uno::Reference< css::container::XNameAccess >
m_xConfigAccess;
struct LocaleSubst
{
- OUString aConfigLocaleString;
+ OUString aConfigLocaleString;
mutable bool bConfigRead;
// note: aSubstAttributes must be sorted alphabetically by Name
// searches on the substitutes are done with Name as key, where
@@ -157,14 +157,14 @@ private:
typedef std::unordered_set< OUString, OUStringHash > UniqueSubstHash;
mutable UniqueSubstHash maSubstHash;
- void fillSubstVector( const com::sun::star::uno::Reference< com::sun::star::container::XNameAccess >& rFont,
+ void fillSubstVector( const css::uno::Reference< css::container::XNameAccess >& rFont,
const OUString& rType,
std::vector< OUString >& rSubstVector ) const;
- FontWeight getSubstWeight( const com::sun::star::uno::Reference< com::sun::star::container::XNameAccess >& rFont,
+ FontWeight getSubstWeight( const css::uno::Reference< css::container::XNameAccess >& rFont,
const OUString& rType ) const;
- FontWidth getSubstWidth( const com::sun::star::uno::Reference< com::sun::star::container::XNameAccess >& rFont,
+ FontWidth getSubstWidth( const css::uno::Reference< css::container::XNameAccess >& rFont,
const OUString& rType ) const;
- ImplFontAttrs getSubstType( const com::sun::star::uno::Reference< com::sun::star::container::XNameAccess >& rFont,
+ ImplFontAttrs getSubstType( const css::uno::Reference< css::container::XNameAccess >& rFont,
const OUString& rType ) const;
void readLocaleSubst( const OUString& rBcp47 ) const;
public:
diff --git a/include/unotools/historyoptions.hxx b/include/unotools/historyoptions.hxx
index e90ba592a4de..71a8d3cb67ef 100644
--- a/include/unotools/historyoptions.hxx
+++ b/include/unotools/historyoptions.hxx
@@ -81,7 +81,7 @@ public:
@param eHistory select right history.
@return A list of history items is returned.
*/
- ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > > GetList(EHistoryType eHistory) const;
+ css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > > GetList(EHistoryType eHistory) const;
/** Append a new item to the specified list.
diff --git a/include/unotools/intlwrapper.hxx b/include/unotools/intlwrapper.hxx
index 903a8a462a0b..30ca525e1523 100644
--- a/include/unotools/intlwrapper.hxx
+++ b/include/unotools/intlwrapper.hxx
@@ -48,7 +48,7 @@ class UNOTOOLS_DLLPUBLIC IntlWrapper
private:
LanguageTag maLanguageTag;
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > m_xContext;
+ css::uno::Reference< css::uno::XComponentContext > m_xContext;
LocaleDataWrapper* pLocaleData;
CollatorWrapper* pCollator;
@@ -59,7 +59,7 @@ private:
public:
IntlWrapper(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > & rxContext,
+ const css::uno::Reference< css::uno::XComponentContext > & rxContext,
const LanguageTag& rLanguageTag
);
IntlWrapper(
diff --git a/include/unotools/lingucfg.hxx b/include/unotools/lingucfg.hxx
index 46a407464871..0f9acb9af6b4 100644
--- a/include/unotools/lingucfg.hxx
+++ b/include/unotools/lingucfg.hxx
@@ -37,11 +37,11 @@ class SvtLinguConfigItem;
struct UNOTOOLS_DLLPUBLIC SvtLinguOptions
{
- ::com::sun::star::uno::Sequence< OUString > aActiveDics;
- ::com::sun::star::uno::Sequence< OUString > aActiveConvDics;
+ css::uno::Sequence< OUString > aActiveDics;
+ css::uno::Sequence< OUString > aActiveConvDics;
- bool bROActiveDics;
- bool bROActiveConvDics;
+ bool bROActiveDics;
+ bool bROActiveConvDics;
// Hyphenator service specific options
sal_Int16 nHyphMinLeading,
@@ -130,11 +130,11 @@ struct UNOTOOLS_DLLPUBLIC SvtLinguOptions
struct UNOTOOLS_DLLPUBLIC SvtLinguConfigDictionaryEntry
{
// the URL's pointing to the location of the files the dictionary consists of
- com::sun::star::uno::Sequence< OUString > aLocations;
+ css::uno::Sequence< OUString > aLocations;
// the name of the dictionary format implement
OUString aFormatName;
// the list of languages (ISO names) the dictionary can be used for
- com::sun::star::uno::Sequence< OUString > aLocaleNames;
+ css::uno::Sequence< OUString > aLocaleNames;
};
class UNOTOOLS_DLLPUBLIC SvtLinguConfig: public utl::detail::Options
@@ -145,9 +145,9 @@ class UNOTOOLS_DLLPUBLIC SvtLinguConfig: public utl::detail::Options
SvtLinguConfigItem & GetConfigItem() const { return const_cast< SvtLinguConfig * >( this )->GetConfigItem(); }
// configuration update access for the 'Linguistic' main node
- mutable com::sun::star::uno::Reference< com::sun::star::util::XChangesBatch > m_xMainUpdateAccess;
+ mutable css::uno::Reference< css::util::XChangesBatch > m_xMainUpdateAccess;
- com::sun::star::uno::Reference< com::sun::star::util::XChangesBatch > GetMainUpdateAccess() const;
+ css::uno::Reference< css::util::XChangesBatch > GetMainUpdateAccess() const;
OUString GetVendorImageUrl_Impl( const OUString &rServiceImplName, const OUString &rImageName ) const;
@@ -160,27 +160,27 @@ public:
// borrowed from utl::ConfigItem
- com::sun::star::uno::Sequence< OUString >
+ css::uno::Sequence< OUString >
GetNodeNames( const OUString &rNode );
- com::sun::star::uno::Sequence< com::sun::star::uno::Any >
+ css::uno::Sequence< css::uno::Any >
GetProperties(
- const com::sun::star::uno::Sequence< OUString > &rNames );
+ const css::uno::Sequence< OUString > &rNames );
bool
ReplaceSetProperties(
const OUString &rNode,
- const com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue >& rValues );
+ const css::uno::Sequence< css::beans::PropertyValue >& rValues );
- com::sun::star::uno::Any
+ css::uno::Any
GetProperty( const OUString &rPropertyName ) const;
- com::sun::star::uno::Any
+ css::uno::Any
GetProperty( sal_Int32 nPropertyHandle ) const;
bool SetProperty( const OUString &rPropertyName,
- const com::sun::star::uno::Any &rValue );
+ const css::uno::Any &rValue );
bool SetProperty( sal_Int32 nPropertyHandle,
- const com::sun::star::uno::Any &rValue );
+ const css::uno::Any &rValue );
bool GetOptions( SvtLinguOptions &rOptions ) const;
@@ -190,13 +190,13 @@ public:
//! the following functions work on the 'ServiceManager' sub node of the
//! linguistic configuration only
//!
- bool GetElementNamesFor( const OUString &rNodeName, com::sun::star::uno::Sequence< OUString > &rElementNames ) const;
+ bool GetElementNamesFor( const OUString &rNodeName, css::uno::Sequence< OUString > &rElementNames ) const;
- bool GetSupportedDictionaryFormatsFor( const OUString &rSetName, const OUString &rSetEntry, com::sun::star::uno::Sequence< OUString > &rFormatList ) const;
+ bool GetSupportedDictionaryFormatsFor( const OUString &rSetName, const OUString &rSetEntry, css::uno::Sequence< OUString > &rFormatList ) const;
bool GetDictionaryEntry( const OUString &rNodeName, SvtLinguConfigDictionaryEntry &rDicEntry ) const;
- com::sun::star::uno::Sequence< OUString > GetDisabledDictionaries() const;
+ css::uno::Sequence< OUString > GetDisabledDictionaries() const;
std::vector< SvtLinguConfigDictionaryEntry > GetActiveDictionariesByFormat( const OUString &rFormatName );
diff --git a/include/unotools/localedatawrapper.hxx b/include/unotools/localedatawrapper.hxx
index 1664ad847fca..a1f559149129 100644
--- a/include/unotools/localedatawrapper.hxx
+++ b/include/unotools/localedatawrapper.hxx
@@ -53,17 +53,17 @@ class UNOTOOLS_DLLPUBLIC LocaleDataWrapper
{
static sal_uInt8 nLocaleDataChecking; // 0:=dontknow, 1:=yes, 2:=no
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > m_xContext;
- ::com::sun::star::uno::Reference< ::com::sun::star::i18n::XLocaleData4 > xLD;
- LanguageTag maLanguageTag;
- std::shared_ptr< ::com::sun::star::i18n::Calendar2 > xDefaultCalendar;
- ::com::sun::star::i18n::LocaleDataItem aLocaleDataItem;
- ::com::sun::star::uno::Sequence< OUString > aReservedWordSeq;
- ::com::sun::star::uno::Sequence< OUString > aDateAcceptancePatterns;
- ::com::sun::star::uno::Sequence< sal_Int32 > aGrouping;
+ css::uno::Reference< css::uno::XComponentContext > m_xContext;
+ css::uno::Reference< css::i18n::XLocaleData4 > xLD;
+ LanguageTag maLanguageTag;
+ std::shared_ptr< css::i18n::Calendar2 > xDefaultCalendar;
+ css::i18n::LocaleDataItem aLocaleDataItem;
+ css::uno::Sequence< OUString > aReservedWordSeq;
+ css::uno::Sequence< OUString > aDateAcceptancePatterns;
+ css::uno::Sequence< sal_Int32 > aGrouping;
// cached items
- OUString aLocaleItem[::com::sun::star::i18n::LocaleItem::COUNT];
- OUString aReservedWord[::com::sun::star::i18n::reservedWords::COUNT];
+ OUString aLocaleItem[css::i18n::LocaleItem::COUNT];
+ OUString aReservedWord[css::i18n::reservedWords::COUNT];
OUString aCurrSymbol;
OUString aCurrBankSymbol;
int nDateFormat;
@@ -108,7 +108,7 @@ class UNOTOOLS_DLLPUBLIC LocaleDataWrapper
public:
LocaleDataWrapper(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > & rxContext,
+ const css::uno::Reference< css::uno::XComponentContext > & rxContext,
const LanguageTag& rLanguageTag
);
LocaleDataWrapper(
@@ -121,8 +121,8 @@ public:
non-existent if this LocaleDataWrapper was created without one and
lives "on the grassland". The CalendarWrapper ctor can handle that
though. */
- const ::com::sun::star::uno::Reference<
- ::com::sun::star::uno::XComponentContext > & getComponentContext()
+ const css::uno::Reference<
+ css::uno::XComponentContext > & getComponentContext()
const { return m_xContext; }
/// set a new Locale to request
@@ -136,25 +136,25 @@ public:
// Wrapper implementations of service LocaleData
- ::com::sun::star::i18n::LanguageCountryInfo getLanguageCountryInfo() const;
- ::com::sun::star::i18n::LocaleDataItem getLocaleItem() const;
+ css::i18n::LanguageCountryInfo getLanguageCountryInfo() const;
+ css::i18n::LocaleDataItem getLocaleItem() const;
/// NOTE: this wraps XLocaleData3::getAllCalendars2() in fact.
- ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::Calendar2 > getAllCalendars() const;
+ css::uno::Sequence< css::i18n::Calendar2 > getAllCalendars() const;
/// NOTE: this wraps XLocaleData2::getAllCurrencies2() in fact.
- ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::Currency2 > getAllCurrencies() const;
- ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::FormatElement > getAllFormats() const;
- ::com::sun::star::i18n::ForbiddenCharacters getForbiddenCharacters() const;
- ::com::sun::star::uno::Sequence< OUString > getReservedWord() const;
- ::com::sun::star::uno::Sequence< ::com::sun::star::lang::Locale > getAllInstalledLocaleNames() const;
- ::com::sun::star::uno::Sequence< OUString > getDateAcceptancePatterns() const;
+ css::uno::Sequence< css::i18n::Currency2 > getAllCurrencies() const;
+ css::uno::Sequence< css::i18n::FormatElement > getAllFormats() const;
+ css::i18n::ForbiddenCharacters getForbiddenCharacters() const;
+ css::uno::Sequence< OUString > getReservedWord() const;
+ css::uno::Sequence< css::lang::Locale > getAllInstalledLocaleNames() const;
+ css::uno::Sequence< OUString > getDateAcceptancePatterns() const;
/** Override locale's date acceptance patterns.
An empty sequence resets the patterns to the locale's pattern sequence.
*/
- void setDateAcceptancePatterns( const ::com::sun::star::uno::Sequence< OUString > & rPatterns );
+ void setDateAcceptancePatterns( const css::uno::Sequence< OUString > & rPatterns );
/// same as the wrapper implementation but static
- static ::com::sun::star::uno::Sequence< ::com::sun::star::lang::Locale > getInstalledLocaleNames();
+ static css::uno::Sequence< css::lang::Locale > getInstalledLocaleNames();
/** Get LanguageTypes for all installed locales which are unambiguous
convertible back and forth between locale ISO strings and MS-LCID
@@ -163,19 +163,19 @@ public:
matching, excluding already known problems.
(e.g. used in number formatter dialog init)
*/
- static ::com::sun::star::uno::Sequence< sal_uInt16 > getInstalledLanguageTypes();
+ static css::uno::Sequence< sal_uInt16 > getInstalledLanguageTypes();
/// maps the LocaleData string to the International enum
MeasurementSystem mapMeasurementStringToEnum( const OUString& rMS ) const;
/// Convenience method to obtain the default calendar.
- const std::shared_ptr< ::com::sun::star::i18n::Calendar2 > getDefaultCalendar() const;
+ const std::shared_ptr< css::i18n::Calendar2 > getDefaultCalendar() const;
/// Convenience method to obtain the day names of the default calendar.
- const ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > getDefaultCalendarDays() const;
+ const css::uno::Sequence< css::i18n::CalendarItem2 > getDefaultCalendarDays() const;
/// Convenience method to obtain the month names of the default calendar.
- const ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > getDefaultCalendarMonths() const;
+ const css::uno::Sequence< css::i18n::CalendarItem2 > getDefaultCalendarMonths() const;
/** Obtain digit grouping. The usually known grouping by thousands (#,###)
is actually only one of possible groupings. Another one, for example,
@@ -187,44 +187,44 @@ public:
Indian grouping. The sal_Int32* getConstArray() can be passed directly
to the ::rtl::math::doubleToString() methods as argument for the
pGroups parameter. */
- const ::com::sun::star::uno::Sequence< sal_Int32 > getDigitGrouping() const;
+ const css::uno::Sequence< sal_Int32 > getDigitGrouping() const;
// Functionality of class International methods, LocaleItem
const OUString& getDateSep() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::DATE_SEPARATOR ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::DATE_SEPARATOR ); }
const OUString& getNumThousandSep() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::THOUSAND_SEPARATOR ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::THOUSAND_SEPARATOR ); }
const OUString& getNumDecimalSep() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::DECIMAL_SEPARATOR ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::DECIMAL_SEPARATOR ); }
const OUString& getTimeSep() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::TIME_SEPARATOR ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::TIME_SEPARATOR ); }
const OUString& getTime100SecSep() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::TIME_100SEC_SEPARATOR ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::TIME_100SEC_SEPARATOR ); }
const OUString& getListSep() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::LIST_SEPARATOR ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::LIST_SEPARATOR ); }
const OUString& getQuotationMarkStart() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::SINGLE_QUOTATION_START ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::SINGLE_QUOTATION_START ); }
const OUString& getQuotationMarkEnd() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::SINGLE_QUOTATION_END ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::SINGLE_QUOTATION_END ); }
const OUString& getDoubleQuotationMarkStart() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::DOUBLE_QUOTATION_START ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::DOUBLE_QUOTATION_START ); }
const OUString& getDoubleQuotationMarkEnd() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::DOUBLE_QUOTATION_END ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::DOUBLE_QUOTATION_END ); }
MeasurementSystem getMeasurementSystemEnum() const
- { return mapMeasurementStringToEnum( getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::MEASUREMENT_SYSTEM ) ); }
+ { return mapMeasurementStringToEnum( getOneLocaleItem( css::i18n::LocaleItem::MEASUREMENT_SYSTEM ) ); }
const OUString& getTimeAM() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::TIME_AM ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::TIME_AM ); }
const OUString& getTimePM() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::TIME_PM ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::TIME_PM ); }
const OUString& getLongDateDayOfWeekSep() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::LONG_DATE_DAY_OF_WEEK_SEPARATOR ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::LONG_DATE_DAY_OF_WEEK_SEPARATOR ); }
const OUString& getLongDateDaySep() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::LONG_DATE_DAY_SEPARATOR ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::LONG_DATE_DAY_SEPARATOR ); }
const OUString& getLongDateMonthSep() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::LONG_DATE_MONTH_SEPARATOR ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::LONG_DATE_MONTH_SEPARATOR ); }
const OUString& getLongDateYearSep() const
- { return getOneLocaleItem( ::com::sun::star::i18n::LocaleItem::LONG_DATE_YEAR_SEPARATOR ); }
+ { return getOneLocaleItem( css::i18n::LocaleItem::LONG_DATE_YEAR_SEPARATOR ); }
// currency
const OUString& getCurrSymbol() const;
@@ -298,16 +298,16 @@ public:
// reserved words
const OUString& getTrueWord() const
- { return getOneReservedWord( ::com::sun::star::i18n::reservedWords::TRUE_WORD ); }
+ { return getOneReservedWord( css::i18n::reservedWords::TRUE_WORD ); }
const OUString& getFalseWord() const
- { return getOneReservedWord( ::com::sun::star::i18n::reservedWords::FALSE_WORD ); }
+ { return getOneReservedWord( css::i18n::reservedWords::FALSE_WORD ); }
const OUString& getAboveWord() const
- { return getOneReservedWord( ::com::sun::star::i18n::reservedWords::ABOVE_WORD ); }
+ { return getOneReservedWord( css::i18n::reservedWords::ABOVE_WORD ); }
const OUString& getBelowWord() const
- { return getOneReservedWord( ::com::sun::star::i18n::reservedWords::BELOW_WORD ); }
+ { return getOneReservedWord( css::i18n::reservedWords::BELOW_WORD ); }
/// return a quarter abbreviation string matching nQuarter (0..3) => "Q1" .. "Q2"
const OUString& getQuarterAbbreviation( sal_Int16 nQuarter ) const
- { return getOneReservedWord( ::com::sun::star::i18n::reservedWords::QUARTER1_ABBREVIATION + nQuarter ); }
+ { return getOneReservedWord( css::i18n::reservedWords::QUARTER1_ABBREVIATION + nQuarter ); }
/** Return whether locale data checks are enabled.
Checks are enabled if the environment variable
@@ -336,7 +336,7 @@ public:
private:
- const ::com::sun::star::lang::Locale & getMyLocale() const;
+ const css::lang::Locale & getMyLocale() const;
static void evaluateLocaleDataChecking();
};
diff --git a/include/unotools/localfilehelper.hxx b/include/unotools/localfilehelper.hxx
index 31cd395db6d8..e96b5a571f28 100644
--- a/include/unotools/localfilehelper.hxx
+++ b/include/unotools/localfilehelper.hxx
@@ -29,7 +29,7 @@ namespace utl
class UNOTOOLS_DLLPUBLIC LocalFileHelper
{
public:
- static ::com::sun::star::uno::Sequence< OUString >
+ static css::uno::Sequence< OUString >
GetFolderContents( const OUString& rFolder, bool bFolder );
};
diff --git a/include/unotools/moduleoptions.hxx b/include/unotools/moduleoptions.hxx
index 23e975cec01d..c884908c8688 100644
--- a/include/unotools/moduleoptions.hxx
+++ b/include/unotools/moduleoptions.hxx
@@ -134,7 +134,7 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtModuleOptions : public utl::detail::
@return A suitable enum value. See EFactory above.
*/
static EFactory ClassifyFactoryByURL(const OUString& sURL ,
- const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >& lMediaDescriptor);
+ const css::uno::Sequence< css::beans::PropertyValue >& lMediaDescriptor);
/** @short return the corresponding application ID for the given properties.
@@ -149,7 +149,7 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtModuleOptions : public utl::detail::
@return A suitable enum value. See EFactory above.
*/
- static EFactory ClassifyFactoryByModel(const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XModel >& xModel);
+ static EFactory ClassifyFactoryByModel(const css::uno::Reference< css::frame::XModel >& xModel);
static OUString GetFactoryShortName(EFactory eFactory);
@@ -164,7 +164,7 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtModuleOptions : public utl::detail::
static bool IsBasicIDE () { return true; }
bool IsDataBase () const;
- ::com::sun::star::uno::Sequence < OUString > GetAllServiceNames();
+ css::uno::Sequence < OUString > GetAllServiceNames();
private:
UNOTOOLS_DLLPRIVATE static ::osl::Mutex& impl_GetOwnStaticMutex();
diff --git a/include/unotools/nativenumberwrapper.hxx b/include/unotools/nativenumberwrapper.hxx
index a6582d27292b..10f6c5deec74 100644
--- a/include/unotools/nativenumberwrapper.hxx
+++ b/include/unotools/nativenumberwrapper.hxx
@@ -30,13 +30,13 @@ namespace com { namespace sun { namespace star {
class UNOTOOLS_DLLPUBLIC NativeNumberWrapper
{
- ::com::sun::star::uno::Reference< ::com::sun::star::i18n::XNativeNumberSupplier > xNNS;
+ css::uno::Reference< css::i18n::XNativeNumberSupplier > xNNS;
NativeNumberWrapper( const NativeNumberWrapper& ) = delete;
NativeNumberWrapper& operator=( const NativeNumberWrapper& ) = delete;
public:
NativeNumberWrapper(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > & rxContext
+ const css::uno::Reference< css::uno::XComponentContext > & rxContext
);
~NativeNumberWrapper();
@@ -45,15 +45,15 @@ public:
OUString getNativeNumberString(
const OUString& rNumberString,
- const ::com::sun::star::lang::Locale& rLocale,
+ const css::lang::Locale& rLocale,
sal_Int16 nNativeNumberMode ) const;
- ::com::sun::star::i18n::NativeNumberXmlAttributes convertToXmlAttributes(
- const ::com::sun::star::lang::Locale& rLocale,
+ css::i18n::NativeNumberXmlAttributes convertToXmlAttributes(
+ const css::lang::Locale& rLocale,
sal_Int16 nNativeNumberMode ) const;
sal_Int16 convertFromXmlAttributes(
- const ::com::sun::star::i18n::NativeNumberXmlAttributes& rAttr ) const;
+ const css::i18n::NativeNumberXmlAttributes& rAttr ) const;
};
diff --git a/include/unotools/numberformatcodewrapper.hxx b/include/unotools/numberformatcodewrapper.hxx
index b41233407d41..08d97fc02097 100644
--- a/include/unotools/numberformatcodewrapper.hxx
+++ b/include/unotools/numberformatcodewrapper.hxx
@@ -31,28 +31,28 @@ namespace com { namespace sun { namespace star {
class UNOTOOLS_DLLPUBLIC NumberFormatCodeWrapper
{
- ::com::sun::star::uno::Reference< ::com::sun::star::i18n::XNumberFormatCode > xNFC;
- ::com::sun::star::lang::Locale aLocale;
+ css::uno::Reference< css::i18n::XNumberFormatCode > xNFC;
+ css::lang::Locale aLocale;
NumberFormatCodeWrapper( const NumberFormatCodeWrapper& ) = delete;
NumberFormatCodeWrapper& operator=( const NumberFormatCodeWrapper& ) = delete;
public:
NumberFormatCodeWrapper(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > & rxContext,
- const ::com::sun::star::lang::Locale& rLocale
+ const css::uno::Reference< css::uno::XComponentContext > & rxContext,
+ const css::lang::Locale& rLocale
);
~NumberFormatCodeWrapper();
/// set a new Locale
- void setLocale( const ::com::sun::star::lang::Locale& rLocale );
+ void setLocale( const css::lang::Locale& rLocale );
// Wrapper implementations of class NumberFormatCodeMapper
- ::com::sun::star::i18n::NumberFormatCode getFormatCode( sal_Int16 nFormatIndex ) const;
- ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::NumberFormatCode > getAllFormatCode( sal_Int16 nFormatUsage ) const;
- ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::NumberFormatCode > getAllFormatCodes() const;
+ css::i18n::NumberFormatCode getFormatCode( sal_Int16 nFormatIndex ) const;
+ css::uno::Sequence< css::i18n::NumberFormatCode > getAllFormatCode( sal_Int16 nFormatUsage ) const;
+ css::uno::Sequence< css::i18n::NumberFormatCode > getAllFormatCodes() const;
};
diff --git a/include/unotools/progresshandlerwrap.hxx b/include/unotools/progresshandlerwrap.hxx
index 05f7d8b514d0..61aff766709c 100644
--- a/include/unotools/progresshandlerwrap.hxx
+++ b/include/unotools/progresshandlerwrap.hxx
@@ -27,20 +27,20 @@
namespace utl
{
-class UNOTOOLS_DLLPUBLIC ProgressHandlerWrap : public ::cppu::WeakImplHelper1< ::com::sun::star::ucb::XProgressHandler >
+class UNOTOOLS_DLLPUBLIC ProgressHandlerWrap : public ::cppu::WeakImplHelper1< css::ucb::XProgressHandler >
{
- ::com::sun::star::uno::Reference< ::com::sun::star::task::XStatusIndicator > m_xStatusIndicator;
+ css::uno::Reference< css::task::XStatusIndicator > m_xStatusIndicator;
public:
- ProgressHandlerWrap( ::com::sun::star::uno::Reference< ::com::sun::star::task::XStatusIndicator > xSI );
+ ProgressHandlerWrap( css::uno::Reference< css::task::XStatusIndicator > xSI );
// XProgressHandler
- virtual void SAL_CALL push( const ::com::sun::star::uno::Any& Status )
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL update( const ::com::sun::star::uno::Any& Status )
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL push( const css::uno::Any& Status )
+ throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL update( const css::uno::Any& Status )
+ throw (css::uno::RuntimeException, std::exception) override;
virtual void SAL_CALL pop()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
};
} // namespace utl
diff --git a/include/unotools/securityoptions.hxx b/include/unotools/securityoptions.hxx
index 77e4720cf20f..8e8fe91d7a77 100644
--- a/include/unotools/securityoptions.hxx
+++ b/include/unotools/securityoptions.hxx
@@ -85,7 +85,7 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtSecurityOptions : public utl::detail
MA_RUN
};
- typedef ::com::sun::star::uno::Sequence< OUString > Certificate;
+ typedef css::uno::Sequence< OUString > Certificate;
/*
// MT: Doesn't work for sequence...
@@ -139,8 +139,8 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtSecurityOptions : public utl::detail
@onerror No error should occur!
*//*-*****************************************************************************************************/
- ::com::sun::star::uno::Sequence< OUString > GetSecureURLs( ) const;
- void SetSecureURLs( const ::com::sun::star::uno::Sequence< OUString >& seqURLList );
+ css::uno::Sequence< OUString > GetSecureURLs( ) const;
+ void SetSecureURLs( const css::uno::Sequence< OUString >& seqURLList );
/*-****************************************************************************************************
@short interface methods to get and set value of config key "org.openoffice.Office.Common/Security/Scripting/StarOfficeBasic"
@@ -188,8 +188,8 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtSecurityOptions : public utl::detail
bool isTrustedLocationUriForUpdatingLinks(OUString const & uri) const;
- ::com::sun::star::uno::Sequence< Certificate > GetTrustedAuthors ( ) const;
- void SetTrustedAuthors ( const ::com::sun::star::uno::Sequence< Certificate >& rAuthors );
+ css::uno::Sequence< Certificate > GetTrustedAuthors ( ) const;
+ void SetTrustedAuthors ( const css::uno::Sequence< Certificate >& rAuthors );
// for bool options only!
bool IsOptionSet ( EOption eOption ) const;
diff --git a/include/unotools/sharedunocomponent.hxx b/include/unotools/sharedunocomponent.hxx
index 7226822e942f..9a293dee9759 100644
--- a/include/unotools/sharedunocomponent.hxx
+++ b/include/unotools/sharedunocomponent.hxx
@@ -43,8 +43,7 @@ namespace utl
*/
class UNOTOOLS_DLLPUBLIC DisposableComponent
{
- ::com::sun::star::uno::Reference< ::com::sun::star::lang::XComponent >
- m_xComponent;
+ css::uno::Reference< css::lang::XComponent > m_xComponent;
public:
/** constructs a ->DisposableComponent instance
@@ -52,7 +51,7 @@ namespace utl
@param _rxComponent
the component whose life time should be controlled by the instance. Must not be <NULL/>.
*/
- DisposableComponent( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxComponent );
+ DisposableComponent( const css::uno::Reference< css::uno::XInterface >& _rxComponent );
/** disposes the component represented by the instance
@@ -88,7 +87,7 @@ namespace utl
@param _rxComponent
the component whose life time should be controlled by the instance. Must not be <NULL/>.
*/
- CloseableComponent( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxComponent );
+ CloseableComponent( const css::uno::Reference< css::uno::XInterface >& _rxComponent );
/** destroys resources associated with this instance, and disposes the component
@@ -141,8 +140,8 @@ namespace utl
typedef std::shared_ptr<Component> ComponentPointer;
private:
- ComponentPointer m_xComponent;
- ::com::sun::star::uno::Reference< INTERFACE > m_xTypedComponent;
+ ComponentPointer m_xComponent;
+ css::uno::Reference< INTERFACE > m_xTypedComponent;
public:
enum AssignmentMode
@@ -156,32 +155,32 @@ namespace utl
{
}
- explicit inline SharedUNOComponent( const ::com::sun::star::uno::Reference< INTERFACE >& _rxComponent, AssignmentMode eMode = TakeOwnership )
+ explicit inline SharedUNOComponent( const css::uno::Reference< INTERFACE >& _rxComponent, AssignmentMode eMode = TakeOwnership )
{
reset( _rxComponent, eMode );
}
- inline SharedUNOComponent( const ::com::sun::star::uno::XInterface* _pInterface, ::com::sun::star::uno::UnoReference_QueryThrow _queryThrow )
+ inline SharedUNOComponent( const css::uno::XInterface* _pInterface, css::uno::UnoReference_QueryThrow _queryThrow )
{
set( _pInterface, _queryThrow );
}
- inline SharedUNOComponent( const ::com::sun::star::uno::BaseReference & _rRef, ::com::sun::star::uno::UnoReference_QueryThrow _queryThrow )
+ inline SharedUNOComponent( const css::uno::BaseReference & _rRef, css::uno::UnoReference_QueryThrow _queryThrow )
{
set( _rRef, _queryThrow );
}
- inline SharedUNOComponent( const ::com::sun::star::uno::Any& _rAny, ::com::sun::star::uno::UnoReference_QueryThrow _queryThrow )
+ inline SharedUNOComponent( const css::uno::Any& _rAny, css::uno::UnoReference_QueryThrow _queryThrow )
{
set( _rAny, _queryThrow );
}
- inline SharedUNOComponent( const SharedUNOComponent& _rxComponent, ::com::sun::star::uno::UnoReference_SetThrow _setThrow )
+ inline SharedUNOComponent( const SharedUNOComponent& _rxComponent, css::uno::UnoReference_SetThrow _setThrow )
{
set( _rxComponent, _setThrow );
}
-// SharedUNOComponent& operator=( const ::com::sun::star::uno::Reference< INTERFACE >& _rxComponent );
+// SharedUNOComponent& operator=( const css::uno::Reference< INTERFACE >& _rxComponent );
// This operator is intentionally not implemented. There is no canonic ownership after this operator
// would have been applied: Should the SharedUNOComponent have the ownership of the component,
// or shouldn't it? Hard to guess, and probably wrong in 50 percent of all cases, anyway. So,
@@ -191,26 +190,26 @@ namespace utl
/** assigns a new component, and releases the old one
*/
- void reset( const ::com::sun::star::uno::Reference< INTERFACE >& _rxComponent, AssignmentMode _eMode = TakeOwnership );
+ void reset( const css::uno::Reference< INTERFACE >& _rxComponent, AssignmentMode _eMode = TakeOwnership );
- inline bool set( const ::com::sun::star::uno::BaseReference& _rRef, ::com::sun::star::uno::UnoReference_Query _query );
+ inline bool set( const css::uno::BaseReference& _rRef, css::uno::UnoReference_Query _query );
- inline void set( const ::com::sun::star::uno::XInterface* _pInterface, ::com::sun::star::uno::UnoReference_QueryThrow _queryThrow );
- inline void set( const ::com::sun::star::uno::BaseReference & _rRef, ::com::sun::star::uno::UnoReference_QueryThrow _queryThrow );
- inline void set( const ::com::sun::star::uno::Any& _rAny, ::com::sun::star::uno::UnoReference_QueryThrow _queryThrow );
+ inline void set( const css::uno::XInterface* _pInterface, css::uno::UnoReference_QueryThrow _queryThrow );
+ inline void set( const css::uno::BaseReference & _rRef, css::uno::UnoReference_QueryThrow _queryThrow );
+ inline void set( const css::uno::Any& _rAny, css::uno::UnoReference_QueryThrow _queryThrow );
- inline void set( const INTERFACE* _pInterface, ::com::sun::star::uno::UnoReference_SetThrow _setThrow );
- inline void set( const ::com::sun::star::uno::Reference< INTERFACE >& _rRef, ::com::sun::star::uno::UnoReference_SetThrow _setThrow );
- inline void set( const SharedUNOComponent& _rComp, ::com::sun::star::uno::UnoReference_SetThrow _setThrow );
+ inline void set( const INTERFACE* _pInterface, css::uno::UnoReference_SetThrow _setThrow );
+ inline void set( const css::uno::Reference< INTERFACE >& _rRef, css::uno::UnoReference_SetThrow _setThrow );
+ inline void set( const SharedUNOComponent& _rComp, css::uno::UnoReference_SetThrow _setThrow );
INTERFACE* SAL_CALL operator->() const;
- operator const ::com::sun::star::uno::Reference< INTERFACE >&() const
+ operator const css::uno::Reference< INTERFACE >&() const
{
return m_xTypedComponent;
}
- const ::com::sun::star::uno::Reference< INTERFACE >& getTyped() const
+ const css::uno::Reference< INTERFACE >& getTyped() const
{
return m_xTypedComponent;
}
@@ -235,7 +234,7 @@ namespace utl
// assignments
template < class INTERFACE, class COMPONENT >
- void SharedUNOComponent< INTERFACE, COMPONENT >::reset( const ::com::sun::star::uno::Reference< INTERFACE >& _rxComponent, AssignmentMode _eMode )
+ void SharedUNOComponent< INTERFACE, COMPONENT >::reset( const css::uno::Reference< INTERFACE >& _rxComponent, AssignmentMode _eMode )
{
m_xComponent.reset(_eMode == TakeOwnership ? new COMPONENT( _rxComponent ) : NULL);
m_xTypedComponent = _rxComponent;
@@ -243,62 +242,62 @@ namespace utl
// comparison operators
template < class INTERFACE, class COMPONENT >
- bool operator==( const ::com::sun::star::uno::Reference< INTERFACE >& _rLHS, const SharedUNOComponent< INTERFACE, COMPONENT >& _rRHS )
+ bool operator==( const css::uno::Reference< INTERFACE >& _rLHS, const SharedUNOComponent< INTERFACE, COMPONENT >& _rRHS )
{
return _rLHS == _rRHS.getTyped();
}
template < class INTERFACE, class COMPONENT >
- bool operator==( const SharedUNOComponent< INTERFACE, COMPONENT >& _rLHS, const ::com::sun::star::uno::Reference< INTERFACE >& _rRHS )
+ bool operator==( const SharedUNOComponent< INTERFACE, COMPONENT >& _rLHS, const css::uno::Reference< INTERFACE >& _rRHS )
{
return _rLHS.getTyped() == _rRHS;
}
// conversion to Any
template < class INTERFACE, class COMPONENT >
- inline void SAL_CALL operator <<= ( ::com::sun::star::uno::Any & rAny, const SharedUNOComponent< INTERFACE, COMPONENT >& value )
+ inline void SAL_CALL operator <<= ( css::uno::Any & rAny, const SharedUNOComponent< INTERFACE, COMPONENT >& value )
{
rAny <<= value.getTyped();
}
template < class INTERFACE, class COMPONENT >
- inline ::com::sun::star::uno::Any SAL_CALL makeAny( const SharedUNOComponent< INTERFACE, COMPONENT >& value )
+ inline css::uno::Any SAL_CALL makeAny( const SharedUNOComponent< INTERFACE, COMPONENT >& value )
{
return makeAny( value.getTyped() );
}
template < class INTERFACE, class COMPONENT >
- void SharedUNOComponent< INTERFACE, COMPONENT >::set( const ::com::sun::star::uno::XInterface* _pInterface, ::com::sun::star::uno::UnoReference_QueryThrow _queryThrow )
+ void SharedUNOComponent< INTERFACE, COMPONENT >::set( const css::uno::XInterface* _pInterface, css::uno::UnoReference_QueryThrow _queryThrow )
{
- reset( ::com::sun::star::uno::Reference< INTERFACE >( _pInterface, _queryThrow ), TakeOwnership );
+ reset( css::uno::Reference< INTERFACE >( _pInterface, _queryThrow ), TakeOwnership );
}
template < class INTERFACE, class COMPONENT >
- void SharedUNOComponent< INTERFACE, COMPONENT >::set( const ::com::sun::star::uno::BaseReference & _rRef, ::com::sun::star::uno::UnoReference_QueryThrow _queryThrow )
+ void SharedUNOComponent< INTERFACE, COMPONENT >::set( const css::uno::BaseReference & _rRef, css::uno::UnoReference_QueryThrow _queryThrow )
{
- reset( ::com::sun::star::uno::Reference< INTERFACE >( _rRef, _queryThrow ), TakeOwnership );
+ reset( css::uno::Reference< INTERFACE >( _rRef, _queryThrow ), TakeOwnership );
}
template < class INTERFACE, class COMPONENT >
- void SharedUNOComponent< INTERFACE, COMPONENT >::set( const ::com::sun::star::uno::Any& _rAny, ::com::sun::star::uno::UnoReference_QueryThrow _queryThrow )
+ void SharedUNOComponent< INTERFACE, COMPONENT >::set( const css::uno::Any& _rAny, css::uno::UnoReference_QueryThrow _queryThrow )
{
- reset( ::com::sun::star::uno::Reference< INTERFACE >( _rAny, _queryThrow ), TakeOwnership );
+ reset( css::uno::Reference< INTERFACE >( _rAny, _queryThrow ), TakeOwnership );
}
template < class INTERFACE, class COMPONENT >
- void SharedUNOComponent< INTERFACE, COMPONENT >::set( const INTERFACE* _pInterface, ::com::sun::star::uno::UnoReference_SetThrow _setThrow )
+ void SharedUNOComponent< INTERFACE, COMPONENT >::set( const INTERFACE* _pInterface, css::uno::UnoReference_SetThrow _setThrow )
{
- reset( ::com::sun::star::uno::Reference< INTERFACE >( _pInterface, _setThrow ), TakeOwnership );
+ reset( css::uno::Reference< INTERFACE >( _pInterface, _setThrow ), TakeOwnership );
}
template < class INTERFACE, class COMPONENT >
- void SharedUNOComponent< INTERFACE, COMPONENT >::set( const ::com::sun::star::uno::Reference< INTERFACE >& _rRef, ::com::sun::star::uno::UnoReference_SetThrow _setThrow )
+ void SharedUNOComponent< INTERFACE, COMPONENT >::set( const css::uno::Reference< INTERFACE >& _rRef, css::uno::UnoReference_SetThrow _setThrow )
{
- reset( ::com::sun::star::uno::Reference< INTERFACE >( _rRef, _setThrow ), TakeOwnership );
+ reset( css::uno::Reference< INTERFACE >( _rRef, _setThrow ), TakeOwnership );
}
template < class INTERFACE, class COMPONENT >
- void SharedUNOComponent< INTERFACE, COMPONENT >::set( const SharedUNOComponent& _rComp, ::com::sun::star::uno::UnoReference_SetThrow _setThrow )
+ void SharedUNOComponent< INTERFACE, COMPONENT >::set( const SharedUNOComponent& _rComp, css::uno::UnoReference_SetThrow _setThrow )
{
*this = _rComp;
// provoke an exception in case the component is NULL
@@ -306,9 +305,9 @@ namespace utl
}
template < class INTERFACE, class COMPONENT >
- bool SharedUNOComponent< INTERFACE, COMPONENT >::set( const ::com::sun::star::uno::BaseReference& _rRef, ::com::sun::star::uno::UnoReference_Query _query )
+ bool SharedUNOComponent< INTERFACE, COMPONENT >::set( const css::uno::BaseReference& _rRef, css::uno::UnoReference_Query _query )
{
- reset( ::com::sun::star::uno::Reference< INTERFACE >( _rRef, _query ) );
+ reset( css::uno::Reference< INTERFACE >( _rRef, _query ) );
return is();
}
diff --git a/include/unotools/textsearch.hxx b/include/unotools/textsearch.hxx
index 76e53df7690d..92690bdfa68b 100644
--- a/include/unotools/textsearch.hxx
+++ b/include/unotools/textsearch.hxx
@@ -104,14 +104,14 @@ public:
class UNOTOOLS_DLLPUBLIC TextSearch
{
- static ::com::sun::star::uno::Reference< ::com::sun::star::util::XTextSearch >
- getXTextSearch( const ::com::sun::star::util::SearchOptions& rPara );
+ static css::uno::Reference< css::util::XTextSearch >
+ getXTextSearch( const css::util::SearchOptions& rPara );
- com::sun::star::uno::Reference < com::sun::star::util::XTextSearch >
+ css::uno::Reference < css::util::XTextSearch >
xTextSearch;
void Init( const SearchParam & rParam,
- const ::com::sun::star::lang::Locale& rLocale );
+ const css::lang::Locale& rLocale );
public:
// rText is the string being searched for
@@ -119,7 +119,7 @@ public:
TextSearch( const SearchParam & rPara, LanguageType nLanguage );
TextSearch( const SearchParam & rPara, const CharClass& rCClass );
- TextSearch( const ::com::sun::star::util::SearchOptions& rPara );
+ TextSearch( const css::util::SearchOptions& rPara );
~TextSearch();
/* search in the (selected) text the search string:
@@ -143,16 +143,16 @@ public:
*/
bool SearchForward( const OUString &rStr,
sal_Int32* pStart, sal_Int32* pEnd,
- ::com::sun::star::util::SearchResult* pRes = 0 );
+ css::util::SearchResult* pRes = 0 );
bool SearchBackward( const OUString &rStr,
sal_Int32* pStart, sal_Int32* pEnd,
- ::com::sun::star::util::SearchResult* pRes = 0 );
+ css::util::SearchResult* pRes = 0 );
- void SetLocale( const ::com::sun::star::util::SearchOptions& rOpt,
- const ::com::sun::star::lang::Locale& rLocale );
+ void SetLocale( const css::util::SearchOptions& rOpt,
+ const css::lang::Locale& rLocale );
/* replace back references in the replace string by the sub expressions from the search result */
- void ReplaceBackReferences( OUString& rReplaceStr, const OUString &rStr, const ::com::sun::star::util::SearchResult& rResult );
+ void ReplaceBackReferences( OUString& rReplaceStr, const OUString &rStr, const css::util::SearchResult& rResult );
};
diff --git a/include/unotools/transliterationwrapper.hxx b/include/unotools/transliterationwrapper.hxx
index 9f93477bac13..900ce9f8c0eb 100644
--- a/include/unotools/transliterationwrapper.hxx
+++ b/include/unotools/transliterationwrapper.hxx
@@ -36,8 +36,7 @@ namespace utl
class UNOTOOLS_DLLPUBLIC TransliterationWrapper
{
- ::com::sun::star::uno::Reference<
- ::com::sun::star::i18n::XExtendedTransliteration > xTrans;
+ css::uno::Reference< css::i18n::XExtendedTransliteration > xTrans;
LanguageTag aLanguageTag;
sal_uInt32 nType;
mutable bool bFirstCall;
@@ -49,8 +48,7 @@ class UNOTOOLS_DLLPUBLIC TransliterationWrapper
void setLanguageLocaleImpl( sal_uInt16 nLang );
public:
- TransliterationWrapper( const ::com::sun::star::uno::Reference<
- ::com::sun::star::uno::XComponentContext > & rxContext,
+ TransliterationWrapper( const css::uno::Reference< css::uno::XComponentContext > & rxContext,
sal_uInt32 nType );
~TransliterationWrapper();
@@ -83,12 +81,12 @@ public:
string is returned. */
OUString transliterate( const OUString& rStr,
sal_Int32 nStart, sal_Int32 nLen,
- ::com::sun::star::uno::Sequence <sal_Int32>* pOffset ) const;
+ css::uno::Sequence <sal_Int32>* pOffset ) const;
// Wrapper implementations of class Transliteration
OUString transliterate( const OUString& rStr, sal_uInt16 nLanguage,
sal_Int32 nStart, sal_Int32 nLen,
- ::com::sun::star::uno::Sequence <sal_Int32>* pOffset );
+ css::uno::Sequence <sal_Int32>* pOffset );
/** If two strings are equal per this transliteration.
Returns the number of matched code points in any case, even if strings
diff --git a/include/unotools/ucbhelper.hxx b/include/unotools/ucbhelper.hxx
index 6234e8e58bb6..1b25c54369e6 100644
--- a/include/unotools/ucbhelper.hxx
+++ b/include/unotools/ucbhelper.hxx
@@ -52,7 +52,7 @@ UNOTOOLS_DLLPUBLIC bool GetTitle(
UNOTOOLS_DLLPUBLIC bool Kill(OUString const & url);
-UNOTOOLS_DLLPUBLIC com::sun::star::uno::Any GetProperty(
+UNOTOOLS_DLLPUBLIC css::uno::Any GetProperty(
OUString const & url, OUString const & property);
UNOTOOLS_DLLPUBLIC bool MakeFolder(
@@ -61,8 +61,8 @@ UNOTOOLS_DLLPUBLIC bool MakeFolder(
/// like mkdir -p
UNOTOOLS_DLLPUBLIC bool ensureFolder(
- com::sun::star::uno::Reference< com::sun::star::uno::XComponentContext > xCtx,
- com::sun::star::uno::Reference< com::sun::star::ucb::XCommandEnvironment > xEnv,
+ css::uno::Reference< css::uno::XComponentContext > xCtx,
+ css::uno::Reference< css::ucb::XCommandEnvironment > xEnv,
const OUString& rFolder, ucbhelper::Content & result) throw();
/// @return the value of the "Size" property of the given content, or zero if
diff --git a/include/unotools/ucbstreamhelper.hxx b/include/unotools/ucbstreamhelper.hxx
index b6c3a1c42ada..dac41c3f2812 100644
--- a/include/unotools/ucbstreamhelper.hxx
+++ b/include/unotools/ucbstreamhelper.hxx
@@ -55,15 +55,15 @@ namespace utl
static SvStream* CreateStream( const OUString& rFileName, StreamMode eOpenMode,
UcbLockBytesHandler* pHandler=0 );
static SvStream* CreateStream( const OUString& rFileName, StreamMode eOpenMode,
- ::com::sun::star::uno::Reference < ::com::sun::star::task::XInteractionHandler >,
+ css::uno::Reference < css::task::XInteractionHandler >,
UcbLockBytesHandler* pHandler=0 );
static SvStream* CreateStream( const OUString& rFileName, StreamMode eOpenMode,
bool bFileExists,
UcbLockBytesHandler* pHandler=0 );
- static SvStream* CreateStream( ::com::sun::star::uno::Reference < ::com::sun::star::io::XInputStream > xStream );
- static SvStream* CreateStream( ::com::sun::star::uno::Reference < ::com::sun::star::io::XStream > xStream );
- static SvStream* CreateStream( ::com::sun::star::uno::Reference < ::com::sun::star::io::XInputStream > xStream, bool bCloseStream );
- static SvStream* CreateStream( ::com::sun::star::uno::Reference < ::com::sun::star::io::XStream > xStream, bool bCloseStream );
+ static SvStream* CreateStream( css::uno::Reference < css::io::XInputStream > xStream );
+ static SvStream* CreateStream( css::uno::Reference < css::io::XStream > xStream );
+ static SvStream* CreateStream( css::uno::Reference < css::io::XInputStream > xStream, bool bCloseStream );
+ static SvStream* CreateStream( css::uno::Reference < css::io::XStream > xStream, bool bCloseStream );
};
}
diff --git a/include/unotools/viewoptions.hxx b/include/unotools/viewoptions.hxx
index 0a39b70bef90..e2b57cd6261b 100644
--- a/include/unotools/viewoptions.hxx
+++ b/include/unotools/viewoptions.hxx
@@ -205,8 +205,8 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtViewOptions : public utl::detail::Op
Every view can handle its own user defined data set.
@onerror In the non-product version, an assertion is made. In a product version, errors are silently ignored.
*//*-*****************************************************************************************************/
- ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue > GetUserData( ) const;
- void SetUserData( const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& lData );
+ css::uno::Sequence< css::beans::NamedValue > GetUserData( ) const;
+ void SetUserData( const css::uno::Sequence< css::beans::NamedValue >& lData );
/*-****************************************************************************************************
@short use it to set/get ONE special user data item directly
@@ -215,9 +215,9 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtViewOptions : public utl::detail::Op
@onerror In the non-product version, an assertion is made. In a product version, errors are silently ignored.
*//*-*****************************************************************************************************/
- ::com::sun::star::uno::Any GetUserItem( const OUString& sName ) const;
- void SetUserItem( const OUString& sName ,
- const ::com::sun::star::uno::Any& aValue );
+ css::uno::Any GetUserItem( const OUString& sName ) const;
+ void SetUserItem( const OUString& sName ,
+ const css::uno::Any& aValue );
// private methods
diff --git a/include/unotools/xmlaccelcfg.hxx b/include/unotools/xmlaccelcfg.hxx
index 722511295647..7f5c56527afe 100644
--- a/include/unotools/xmlaccelcfg.hxx
+++ b/include/unotools/xmlaccelcfg.hxx
@@ -33,7 +33,7 @@ struct SvtAcceleratorConfigItem
#include <list>
typedef ::std::list < SvtAcceleratorConfigItem > SvtAcceleratorItemList;
-class OReadAccelatorDocumentHandler : public ::com::sun::star::xml::sax::XDocumentHandler,
+class OReadAccelatorDocumentHandler : public css::xml::sax::XDocumentHandler,
public ::cppu::OWeakObject
{
public:
@@ -50,37 +50,37 @@ class OReadAccelatorDocumentHandler : public ::com::sun::star::xml::sax::XDocume
{ OWeakObject::acquire(); }
virtual void SAL_CALL release() throw() override
{ OWeakObject::release(); }
- virtual ::com::sun::star::uno::Any SAL_CALL queryInterface(
- const ::com::sun::star::uno::Type & rType ) throw( ::com::sun::star::uno::RuntimeException, std::exception ) override;
+ virtual css::uno::Any SAL_CALL queryInterface(
+ const css::uno::Type & rType ) throw( css::uno::RuntimeException, std::exception ) override;
// XDocumentHandler
virtual void SAL_CALL startDocument()
- throw ( ::com::sun::star::xml::sax::SAXException, ::com::sun::star::uno::RuntimeException, std::exception ) override;
+ throw ( css::xml::sax::SAXException, css::uno::RuntimeException, std::exception ) override;
virtual void SAL_CALL endDocument()
- throw ( ::com::sun::star::xml::sax::SAXException, ::com::sun::star::uno::RuntimeException, std::exception ) override;
+ throw ( css::xml::sax::SAXException, css::uno::RuntimeException, std::exception ) override;
virtual void SAL_CALL startElement(
const OUString& aName,
- const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList > &xAttribs )
- throw( ::com::sun::star::xml::sax::SAXException, ::com::sun::star::uno::RuntimeException, std::exception ) override;
+ const css::uno::Reference< css::xml::sax::XAttributeList > &xAttribs )
+ throw( css::xml::sax::SAXException, css::uno::RuntimeException, std::exception ) override;
virtual void SAL_CALL endElement(const OUString& aName) throw
- ( ::com::sun::star::xml::sax::SAXException, ::com::sun::star::uno::RuntimeException, std::exception ) override;
+ ( css::xml::sax::SAXException, css::uno::RuntimeException, std::exception ) override;
virtual void SAL_CALL characters(const OUString& aChars)
- throw( ::com::sun::star::xml::sax::SAXException, ::com::sun::star::uno::RuntimeException, std::exception ) override;
+ throw( css::xml::sax::SAXException, css::uno::RuntimeException, std::exception ) override;
virtual void SAL_CALL ignorableWhitespace(const OUString& aWhitespaces)
- throw( ::com::sun::star::xml::sax::SAXException, ::com::sun::star::uno::RuntimeException, std::exception ) override;
+ throw( css::xml::sax::SAXException, css::uno::RuntimeException, std::exception ) override;
virtual void SAL_CALL processingInstruction( const OUString& aTarget, const OUString& aData )
- throw( ::com::sun::star::xml::sax::SAXException, ::com::sun::star::uno::RuntimeException, std::exception ) override;
+ throw( css::xml::sax::SAXException, css::uno::RuntimeException, std::exception ) override;
virtual void SAL_CALL setDocumentLocator(
- const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XLocator > &xLocator)
- throw( ::com::sun::star::xml::sax::SAXException, ::com::sun::star::uno::RuntimeException, std::exception ) override;
+ const css::uno::Reference< css::xml::sax::XLocator > &xLocator)
+ throw( css::xml::sax::SAXException, css::uno::RuntimeException, std::exception ) override;
private:
OUString getErrorLineString();
int m_nElementDepth;
- bool m_bAcceleratorMode;
- bool m_bItemCloseExpected;
- ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XLocator > m_xLocator;
+ bool m_bAcceleratorMode;
+ bool m_bItemCloseExpected;
+ css::uno::Reference< css::xml::sax::XLocator > m_xLocator;
SvtAcceleratorItemList& m_aReadAcceleratorList;
};
diff --git a/include/unotools/mediadescriptor.hxx b/include/unotools/mediadescriptor.hxx
index 32abafddbf63..f24ed86f8c44 100644
--- a/include/unotools/mediadescriptor.hxx
+++ b/include/unotools/mediadescriptor.hxx
@@ -36,7 +36,7 @@ namespace comphelper { class IDocPasswordVerifier; }
namespace utl {
/** @short can be used to work with a ::com::sun::star::document::MediaDescriptor
struct.
@descr It wraps a unordered_map around the Sequence< css::beans::PropertyValue >, which
@@ -110,7 +110,7 @@ class UNOTOOLS_DLLPUBLIC MediaDescriptor : public comphelper::SequenceAsHashMap
the default ctors of the compiler :-(.
*/
MediaDescriptor();
- MediaDescriptor(const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >& lSource);
+ MediaDescriptor(const css::uno::Sequence< css::beans::PropertyValue >& lSource);
/** @short it checks if the descriptor already has a valid
InputStream item and creates a new one, if not.
@@ -177,7 +177,7 @@ class UNOTOOLS_DLLPUBLIC MediaDescriptor : public comphelper::SequenceAsHashMap
sequence of the 'ComponentData' property, otherwise an empty
Any.
*/
- ::com::sun::star::uno::Any getComponentDataEntry(
+ css::uno::Any getComponentDataEntry(
const OUString& rName ) const;
/** Inserts a value into the sequence contained in the property
@@ -197,7 +197,7 @@ class UNOTOOLS_DLLPUBLIC MediaDescriptor : public comphelper::SequenceAsHashMap
*/
void setComponentDataEntry(
const OUString& rName,
- const ::com::sun::star::uno::Any& rValue );
+ const css::uno::Any& rValue );
/** Removes a value from the sequence contained in the property
'ComponentData' of the media descriptor.
@@ -253,7 +253,7 @@ class UNOTOOLS_DLLPUBLIC MediaDescriptor : public comphelper::SequenceAsHashMap
passed password verifier. If empty, no valid password has been
found, or the user has chossen to cancel password input.
*/
- ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue > requestAndVerifyDocPassword(
+ css::uno::Sequence< css::beans::NamedValue > requestAndVerifyDocPassword(
comphelper::IDocPasswordVerifier& rVerifier,
comphelper::DocPasswordRequestType eRequestType,
const ::std::vector< OUString >* pDefaultPasswords = 0 );
@@ -281,8 +281,8 @@ class UNOTOOLS_DLLPUBLIC MediaDescriptor : public comphelper::SequenceAsHashMap
if the given PostData stream is <NULL/>.
*/
SAL_DLLPRIVATE bool impl_openStreamWithPostData(
- const ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream >& _rxPostData
- ) throw(::com::sun::star::uno::RuntimeException);
+ const css::uno::Reference< css::io::XInputStream >& _rxPostData
+ ) throw(css::uno::RuntimeException);
/** @short tries to open a stream by using the given URL.
@@ -308,7 +308,7 @@ class UNOTOOLS_DLLPUBLIC MediaDescriptor : public comphelper::SequenceAsHashMap
SAL_DLLPRIVATE bool impl_openStreamWithURL(
const OUString& sURL,
bool bLockFile
- ) throw(::com::sun::star::uno::RuntimeException);
+ ) throw(css::uno::RuntimeException);
/** @short it checks if the descriptor already has a valid
InputStream item and creates a new one, if not.
@@ -36,7 +36,7 @@ namespace comphelper { class IDocPasswordVerifier; }
namespace utl {
-/** @short can be used to work with a ::com::sun::star::document::MediaDescriptor
+/** @short can be used to work with a css::document::MediaDescriptor
struct.